<?php


namespace Schaffen\Financial\Payment\DTOs;


class GeneratePaymentInput
{
    protected $parCodigo;
    protected $dataPagamento;
    protected $patrimonial;
    protected $jurosAdicionais;
    protected $adicional;
    protected $multa;
    protected $jurosAtraso;
    protected $desconto;
    protected $pagamento;
    protected $observacao;
    protected $retornoBoleto;
    protected $quitacaoRapida;
    private int $moeda;


    public function __construct($parCodigo, $dataPagamento, $patrimonial, $jurosAdicionais, $adicional,
                                $multa, $jurosAtraso, $desconto, $pagamento, $moeda = 0,
                                $observacao = '', $retornoBoleto = null, $quitacaoRapida = null)
    {
        $this->parCodigo = $parCodigo;
        $this->dataPagamento = $dataPagamento;
        $this->patrimonial = $patrimonial;
        $this->jurosAdicionais = $jurosAdicionais;
        $this->adicional = $adicional;
        $this->multa = $multa;
        $this->jurosAtraso = $jurosAtraso;
        $this->desconto = $desconto;
        $this->pagamento = $pagamento;
        $this->observacao = $observacao;
        $this->retornoBoleto = $retornoBoleto;
        $this->quitacaoRapida = $quitacaoRapida;
        $this->moeda = $moeda;
    }

    public function toPaymentArray(){
        return [
            "pag_data" => $this->dataPagamento,
            "pag_obs" => (empty($this->retornoBoleto) ? "[PAGMANUAL]" : "[PAGBOLETO]") . $this->observacao,
            "pag_valor_total" => $this->pagamento,
            "pag_patrimonial" => $this->patrimonial,
        ];
    }

    public function toAssociateWithInstallmentArray(){
        return [
            "ppg_fk_par_codigo" => $this->parCodigo,
            "ppg_juros_atraso" => $this->jurosAtraso,
            "ppg_multa" => $this->multa,
            "ppg_juros_adicionais" => $this->jurosAdicionais,
            "ppg_valor_adicional" => $this->adicional,
            "ppg_valor_moeda" => $this->moeda,
            "ppg_desconto" => $this->desconto,
            "ppg_valor_pago" => $this->pagamento,
        ];
    }
    public function toArray(){
        return [
            "parCodigo" => $this->parCodigo,
            "dataPagamento" => $this->dataPagamento,
            "patrimonial" => $this->patrimonial,
            "jurosAdicionais" => $this->jurosAdicionais,
            "adicional" => $this->adicional,
            "multa" => $this->multa,
            "jurosAtraso" => $this->jurosAtraso,
            "desconto" => $this->desconto,
            "pagamento" => $this->pagamento,
            "observacao" => $this->observacao,
            "retornoBoleto" => $this->retornoBoleto,
            "quitacaoRapida" => $this->quitacaoRapida,
            "moeda" => $this->moeda,
        ];
    }

    /**
     * @return int|mixed
     */
    public function getParCodigo()
    {
        return $this->parCodigo;
    }

    /**
     * @param int|mixed $parCodigo
     */
    public function setParCodigo($parCodigo): void
    {
        $this->parCodigo = $parCodigo;
    }

    /**
     * @return mixed
     */
    public function getPatrimonial()
    {
        return $this->patrimonial;
    }

    /**
     * @param mixed $patrimonial
     */
    public function setPatrimonial($patrimonial): void
    {
        $this->patrimonial = $patrimonial;
    }

    /**
     * @return mixed|null
     */
    public function getQuitacaoRapida()
    {
        return $this->quitacaoRapida;
    }

    /**
     * @param mixed|null $quitacaoRapida
     */
    public function setQuitacaoRapida($quitacaoRapida): void
    {
        $this->quitacaoRapida = $quitacaoRapida;
    }

    /**
     * @return mixed
     */
    public function getDataPagamento()
    {
        return $this->dataPagamento;
    }

    /**
     * @param mixed $dataPagamento
     */
    public function setDataPagamento($dataPagamento): void
    {
        $this->dataPagamento = $dataPagamento;
    }

    /**
     * @return mixed
     */
    public function getJurosAdicionais()
    {
        return $this->jurosAdicionais;
    }

    /**
     * @param mixed $jurosAdicionais
     */
    public function setJurosAdicionais($jurosAdicionais): void
    {
        $this->jurosAdicionais = $jurosAdicionais;
    }

    /**
     * @return mixed
     */
    public function getAdicional()
    {
        return $this->adicional;
    }

    /**
     * @param mixed $adicional
     */
    public function setAdicional($adicional): void
    {
        $this->adicional = $adicional;
    }

    /**
     * @return mixed
     */
    public function getMulta()
    {
        return $this->multa;
    }

    /**
     * @param mixed $multa
     */
    public function setMulta($multa): void
    {
        $this->multa = $multa;
    }

    /**
     * @return mixed
     */
    public function getJurosAtraso()
    {
        return $this->jurosAtraso;
    }

    /**
     * @param mixed $jurosAtraso
     */
    public function setJurosAtraso($jurosAtraso): void
    {
        $this->jurosAtraso = $jurosAtraso;
    }

    /**
     * @return mixed
     */
    public function getDesconto()
    {
        return $this->desconto;
    }

    /**
     * @param mixed $desconto
     */
    public function setDesconto($desconto): void
    {
        $this->desconto = $desconto;
    }

    /**
     * @return mixed
     */
    public function getPagamento()
    {
        return $this->pagamento;
    }

    /**
     * @param mixed $pagamento
     */
    public function setPagamento($pagamento): void
    {
        $this->pagamento = $pagamento;
    }

    /**
     * @return mixed|string
     */
    public function getObservacao()
    {
        return $this->observacao;
    }

    /**
     * @param mixed|string $observacao
     */
    public function setObservacao($observacao): void
    {
        $this->observacao = $observacao;
    }

    /**
     * @return mixed|null
     */
    public function getRetornoBoleto()
    {
        return $this->retornoBoleto;
    }

    /**
     * @param mixed|null $retornoBoleto
     */
    public function setRetornoBoleto($retornoBoleto): void
    {
        $this->retornoBoleto = $retornoBoleto;
    }

    /**
     * @return int|mixed
     */
    public function getMoeda()
    {
        return $this->moeda;
    }

    /**
     * @param int|mixed $moeda
     */
    public function setMoeda($moeda): void
    {
        $this->moeda = $moeda;
    }
}